@@ -226,29 +226,40 @@ def cluster_node_count(
 ) -> None:
     """Count the number of nodes in the cluster.
 
-    \b
-    The state refers to the state of PostgreSQL. Possible values are:
-    * initializing new cluster, initdb failed
-    * running custom bootstrap script, custom bootstrap failed
-    * starting, start failed
-    * restarting, restart failed
-    * running, streaming (for a replica V3.0.4)
-    * stopping, stopped, stop failed
-    * creating replica
-    * crashed
-
     \b
     The role refers to the role of the server in the cluster. Possible values
     are:
-    * master or leader (V3.0.0+)
+    * master or leader
     * replica
+    * standby_leader
+    * sync_standby
     * demoted
     * promoted
     * uninitialized
 
+    \b
+    The state refers to the state of PostgreSQL. Possible values are:
+    * initializing new cluster, initdb failed
+    * running custom bootstrap script, custom bootstrap failed
+    * starting, start failed
+    * restarting, restart failed
+    * running, streaming, in archive recovery
+    * stopping, stopped, stop failed
+    * creating replica
+    * crashed
+
+    \b
+    The "healthy" checks only ensures that:
+    * a leader has the running state
+    * a standby_leader has the running or streaming (V3.0.4) state
+    * a replica or sync-standby has the running or streaming (V3.0.4) state
+
+    Since we dont check the lag or timeline, "in archive recovery" is not considered a valid state
+    for this service. See cluster_has_leader and cluster_has_replica for specialized checks.
+
     \b
     Check:
-    * Compares the number of nodes against the normal and healthy (running + streaming) nodes warning and critical thresholds.
+    * Compares the number of nodes against the normal and healthy nodes warning and critical thresholds.
     * `OK`:  If they are not provided.
 
     \b
@@ -285,17 +296,38 @@ def cluster_has_leader(ctx: click.Context) -> None:
 
     This check applies to any kind of leaders including standby leaders.
 
+    A leader is a node with the "leader" role and a "running" state.
+
+    A standby leader is a node with a "standby_leader" role and a "streaming"
+    or "in archive recovery" state. Please note that log shipping could be
+    stuck because the WAL are not available or applicable. Patroni doesn't
+    provide information about the origin cluster (timeline or lag), so we
+    cannot check if there is a problem in that particular case. That's why we
+    issue a warning when the node is "in archive recovery". We suggest using
+    other supervision tools to do this (eg. check_pgactivity).
+
     \b
     Check:
     * `OK`: if there is a leader node.
-    * `CRITICAL`: otherwise
+    * 'WARNING': if there is a stanby leader in archive mode.
+    * `CRITICAL`: otherwise.
+
+    \b
+    Perfdata:
+    * `has_leader` is 1 if there is any kind of leader node, 0 otherwise
+    * `is_standby_leader_in_arc_rec` is 1 if the standby leader node is "in
+       archive recovery", 0 otherwise
+    * `is_standby_leader` is 1 if there is a standby leader node, 0 otherwise
+    * `is_leader` is 1 if there is a "classical" leader node, 0 otherwise
 
-    Perfdata: `has_leader` is 1 if there is a leader node, 0 otherwise
     """
     check = nagiosplugin.Check()
     check.add(
         ClusterHasLeader(ctx.obj.connection_info),
         nagiosplugin.ScalarContext("has_leader", None, "@0:0"),
+        nagiosplugin.ScalarContext("is_standby_leader_in_arc_rec", "@1:1", None),
+        nagiosplugin.ScalarContext("is_leader", None, None),
+        nagiosplugin.ScalarContext("is_standby_leader", None, None),
         ClusterHasLeaderSummary(),
     )
     check.main(verbose=ctx.obj.verbose, timeout=ctx.obj.timeout)
@@ -341,11 +373,29 @@ def cluster_has_replica(
 ) -> None:
     """Check if the cluster has healthy replicas and/or if some are sync standbies
 
+    \b
+    For patroni (and this check):
+    * a replica is `streaming` if the `pg_stat_wal_receiver` say's so.
+    * a replica is `in archive recovery`, if it's not `streaming` and has a `restore_command`.
+
     \b
     A healthy replica:
-    * is in running or streaming state (V3.0.4)
-    * has a replica or sync_standby role
-    * has a lag lower or equal to max_lag
+    * has a `replica` or `sync_standby` role
+    * has the same timeline as the leader and
+      * is in `running` state (patroni < V3.0.4)
+      * is in `streaming` or `in archive recovery` state (patroni >= V3.0.4)
+    * has a lag lower or equal to `max_lag`
+
+    Please note that replica `in archive recovery` could be stuck because the WAL
+    are not available or applicable (the server's timeline has diverged for the
+    leader's). We already detect the latter but we will miss the former.
+    Therefore, it's preferable to check for the lag in addition to the healthy
+    state if you rely on log shipping to help lagging standbies to catch up.
+
+    Since we require a healthy replica to have the same timeline as the
+    leader, it's possible that we raise alerts when the cluster is performing a
+    switchover or failover and the standbies are in the process of catching up with
+    the new leader. The alert shouldn't last long.
 
     \b
     Check:
@@ -357,8 +407,9 @@ def cluster_has_replica(
     Perfdata:
     * healthy_replica & unhealthy_replica count
     * the number of sync_replica, they are included in the previous count
-    * the lag of each replica labelled with  "member name"_lag
-    * a boolean to tell if the node is a sync stanbdy labelled with  "member name"_sync
+    * the lag of each replica labelled with "member name"_lag
+    * the timeline of each replica labelled with "member name"_timeline
+    * a boolean to tell if the node is a sync stanbdy labelled with "member name"_sync
     """
 
     tmax_lag = size_to_byte(max_lag) if max_lag is not None else None
@@ -377,6 +428,7 @@ def cluster_has_replica(
         ),
         nagiosplugin.ScalarContext("unhealthy_replica"),
         nagiosplugin.ScalarContext("replica_lag"),
+        nagiosplugin.ScalarContext("replica_timeline"),
         nagiosplugin.ScalarContext("replica_sync"),
     )
     check.main(verbose=ctx.obj.verbose, timeout=ctx.obj.timeout)
@@ -569,10 +621,20 @@ def node_is_leader(ctx: click.Context, check_standby_leader: bool) -> None:
 def node_is_replica(
     ctx: click.Context, max_lag: str, check_is_sync: bool, check_is_async: bool
 ) -> None:
-    """Check if the node is a running replica with no noloadbalance tag.
+    """Check if the node is a replica with no noloadbalance tag.
 
-    It is possible to check if the node is synchronous or asynchronous. If nothing is specified any kind of replica is accepted.
-    When checking for a synchronous replica, it's not possible to specify a lag.
+    It is possible to check if the node is synchronous or asynchronous. If
+    nothing is specified any kind of replica is accepted.  When checking for a
+    synchronous replica, it's not possible to specify a lag.
+
+    This service is using the following Patroni endpoints: replica, asynchronous
+    and synchronous. The first two implement the `lag` tag. For these endpoints
+    the state of a replica node doesn't reflect the replication state
+    (`streaming` or `in archive recovery`), we only know if it's `running`. The
+    timeline is also not checked.
+
+    Therefore, if a cluster is using asynchronous replication, it is
+    recommended to check for the lag to detect a divegence as soon as possible.
 
     \b
     Check:
@@ -610,7 +672,7 @@ def node_is_pending_restart(ctx: click.Context) -> None:
     """Check if the node is in pending restart state.
 
     This situation can arise if the configuration has been modified but
-    requiers a restart of PostgreSQL to take effect.
+    requires a restart of PostgreSQL to take effect.
 
     \b
     Check:
